# Fact Sheet Mapping from SAP LeanIX to Collibra
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#introduction)
  * [Configuring Mapping of Fact Sheets to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#configuring-mapping-of-fact-sheets-to-collibra)
  * [Activating the Mapping and Filtering Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#activating-the-mapping-and-filtering-fact-sheets)
  * [Choosing Inbox Domain and Asset Type](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#choosing-inbox-domain-and-asset-type)
  * [Matching Strategy](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#matching-strategy)
  * [Mapping Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#mapping-fields)
  * [Mapping Subscriptions to Responsibilities](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#mapping-subscriptions-to-responsibilities)
  * [Soft Delete](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#soft-delete)
  * [Hierarchy Mapping](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra#hierarchy-mapping)


Configure the mapping of application, business capability, and interface fact sheets from SAP LeanIX to Collibra to synchronize fields and subscriptions.
